Index: /main/waeup.fceokene/trunk/src/waeup/fceokene/applicants/schools_utp.py
===================================================================
--- /main/waeup.fceokene/trunk/src/waeup/fceokene/applicants/schools_utp.py	(revision 17961)
+++ /main/waeup.fceokene/trunk/src/waeup/fceokene/applicants/schools_utp.py	(revision 17962)
@@ -1,46 +1,44 @@
 SCHOOLS_UTP = {
     'utp0001': ('Zone 01','Otite, Ogaminana, Obangede','Adavi Local Govt. Science Secondary School, Nagazi Eba'),
-    'utp0002': ('Zone 01','Otite, Ogaminana, Obangede','Champion Group Of Schools (Secondary Section), Eika Adagu'),
+    'utp0002': ('Zone 01','Otite, Ogaminana, Obangede','Champion Group Of Schools (Secondary Section), Eika Adagu I'),
     'utp0003': ('Zone 01','Otite, Ogaminana, Obangede','De-Icon Stars International School, Kabba Junction'),
-    'utp0004': ('Zone 01','Otite, Ogaminana, Obangede','Ebira Community Secondary School, Ogaminana'),
-    'utp0005': ('Zone 01','Otite, Ogaminana, Obangede','Government Science Secondary School, Ogaminana '),
+    'utp0004': ('Zone 01','Otite, Ogaminana, Obangede','Ebira Community Secondary School , Ogaminana I'),
+    'utp0005': ('Zone 01','Otite, Ogaminana, Obangede','Government Science Secondary School, Ogaminana I'),
     'utp0006': ('Zone 01','Otite, Ogaminana, Obangede','Audu Wokili Academy, Nagazi Uvete'),
     'utp0007': ('Zone 01','Otite, Ogaminana, Obangede','Acess Secondary school, nagazi uvete'),
-    'utp0009': ('Zone 01','Otite, Ogaminana, Obangede','LENNON MEMORIAL COLLEGE AGEVA'),
-    'utp0010': ('Zone 01','Otite, Ogaminana, Obangede','Community Secondary School, Obangede'),
     'utp0011': ('Zone 01','Otite, Ogaminana, Obangede','NIOMP Staff Secondary School, Itakpe'),
     'utp0012': ('Zone 01','Otite, Ogaminana, Obangede','LGEA UBE SEC. School, Nagazi Uvete, opposite ECSS Ogaminana'),
-    'utp0013': ('Zone 01','Otite, Ogaminana, Obangede','Achievers International College, Nagazi'),
-    'utp0014': ('Zone 01','Otite, Ogaminana, Obangede','Unity Model Secondary School, FCE Okene'),
-    'utp0015': ('Zone 01','Otite, Ogaminana, Obangede','MIKAB College, Nagazi'),
+    'utp0014': ('Zone 01','Otite, Ogaminana, Obangede','Unity Model Secondary School, FCE Okene I'),
     'utp0016': ('Zone 01','Otite, Ogaminana, Obangede','LGEA UBE MODEL SEC.  SCHOOL, ADAVI SECRETARIAT'),
     'utp0017': ('Zone 01','Otite, Ogaminana, Obangede','ABDULAZEEZ ATTAH MEMORIAL COLLEGE, OKENE'),
-    'utp0020': ('Zone 01','Otite, Ogaminana, Obangede','PRINCE OF PEACE ACADEMY, KABBA JUNCTION'),
-    'utp0021': ('Zone 01','Otite, Ogaminana, Obangede','LGEA UBE SCHOOL ABOBO OPPOSITE NIOMP GATE'),
-    'utp0022': ('Zone 01','Otite, Ogaminana, Obangede','OKOMANYI GROUP OF SCHOOLS (SECONDARY SECTION)'),
-    'utp0023': ('Zone 01','Otite, Ogaminana, Obangede','WISDOM DOMINION INTERNATIONAL SCHOOL, ADAVI EBA'),
-    'utp0027': ('Zone 01','Otite, Ogaminana, Obangede','Soladad International School, GRA, Okene'),
-    'utp0030': ('Zone 01','Otite, Ogaminana, Obangede','Government Day Secondary School, Inoziomi'),
+    'utp0022': ('Zone 01','Otite, Ogaminana, Obangede','OKOMANYI GROUP OF SCHOOLS'),
     'utp0031': ('Zone 01','Otite, Ogaminana, Obangede','Ebira Muslim Community College, Okengwe'),
-    'utp0032': ('Zone 01','Otite, Ogaminana, Obangede','Gifted Academy, Nagazi-eba'),
      # Additional School 22/04/2022
     'utp0041': ('Zone 01','Otite, Ogaminana, Obangede','Amazing Grace Secondary School, Nagazi-Uvete'),
-    'utp0042': ('Zone 01','Otite, Ogaminana, Obangede','UBE/JSS Ozuri Ogaminana'),
     'utp0043': ('Zone 01','Otite, Ogaminana, Obangede','Science Leadership Academy, Eika Adagu'),
-    'utp0044': ('Zone 01','Otite, Ogaminana, Obangede','Queen of Apostle College, Okene'),
     # Additional School 29/03/2023
     'utp0048': ('Zone 01','Otite, Ogaminana, Obangede','Unity Model Secondary School, FCE Okene II'),
     'utp0049': ('Zone 01','Otite, Ogaminana, Obangede','Ebira Community Secondary School, Ogaminana II'),
     'utp0050': ('Zone 01','Otite, Ogaminana, Obangede','Government Science Secondary School, Ogaminana II'),
-    'utp0051': ('Zone 01','Otite, Ogaminana, Obangede','NIOMP Staff Secondary School, Itakpe II'),
     # Additional School 13/03/2024
     'utp0052': ('Zone 01','Otite, Ogaminana, Obangede','A One Comprehensive School, Eika Adagu'),
     'utp0053': ('Zone 01','Otite, Ogaminana, Obangede','Higher Ground Academy, Nagazi'),
-    'utp0054': ('Zone 01','Otite, Ogaminana, Obangede','Community Secondary School, Eika-Ohizeruyi'),
-    'utp0055': ('Zone 01','Otite, Ogaminana, Obangede','Community Secondary School, Kuroko'),
-    'utp0056': ('Zone 01','Otite, Ogaminana, Obangede','Williesth Intl School, Abobo'),
-    'utp0057': ('Zone 01','Otite, Ogaminana, Obangede','LGEA UBE Sec. School, Opposite Rio Hotel, Nagazi Uvete'),
+    'utp0057': ('Zone 01','Otite, Ogaminana, Obangede','LGEA UBE Sec. School, Opposite Rio Hotel, Eika Adagu I'),
     'utp0058': ('Zone 01','Otite, Ogaminana, Obangede','FAAAZ International Academy, Nagazi'),
     # Additional School  18/03/2024
-    'utp0059': ('Zone 01','Otite, Ogaminana, Obangede','Champion Group Of Schools 2 (Secondary Section), Eika Adagu'), 
-}
+    'utp0059': ('Zone 01','Otite, Ogaminana, Obangede','Champion Group Of Schools (Secondary Section), Eika Adagu II'),
+    # Additional School  20/11/2024
+    'utp0060': ('Zone 01','Otite, Ogaminana, Obangede','Government Science Secondary School, Ogaminana III'),
+    'utp0061': ('Zone 01','Otite, Ogaminana, Obangede','LGEA UBE Sec. School, Opposite Rio Hotel, Eika Adagu II'),
+    'utp0062': ('Zone 01','Otite, Ogaminana, Obangede','De Great Monarch Academy, Opposite Majid Filling Stattion, Eika Adagu'),
+    'utp0063': ('Zone 01','Otite, Ogaminana, Obangede','De Great Monarch Academy, Opposite Majid Filling Stattion, Eika Adagu'),
+    'utp0064': ('Zone 01','Otite, Ogaminana, Obangede','Start Smart Secondary School, Eika Adagu'),
+    'utp0065': ('Zone 01','Otite, Ogaminana, Obangede','Success College, Ozuri'),
+    'utp0066': ('Zone 02','Okene Metropolis','Government Girls Secondary School, Otutu'),
+    'utp0067': ('Zone 03','Kuroko-Inoziomi-GRA','Government Science Secondary School, Enyidudu-Inuziomi'),
+    'utp0068': ('zone 05','Adogo Ajaokuta','Community Comprehensive High School,Eganyi, Kogi State'),
+    'utp0069': ('Zone 07','Kabba Aiyetoro Gbedde','St. Augustine College, Kabba'),
+    'utp0070': ('Zone 07','Kabba Aiyetoro Gbedde','St. Barnabas Secondary School, Kabba'),
+    'utp0071': ('Zone 07','Kabba Aiyetoro Gbedde','St. Monica College, Kabba'),
+    'utp0072': ('Zone 11','Lokoja','Army Day Secondary School, Lokoja'),
+}   
Index: /main/waeup.fceokene/trunk/src/waeup/fceokene/applicants/tests/test_browser.py
===================================================================
--- /main/waeup.fceokene/trunk/src/waeup/fceokene/applicants/tests/test_browser.py	(revision 17961)
+++ /main/waeup.fceokene/trunk/src/waeup/fceokene/applicants/tests/test_browser.py	(revision 17962)
@@ -318,5 +318,5 @@
         self.browser.open(self.utpapplicant_path + '/edit')
         self.browser.getControl(name="form.email").value = 'xx@yy.zz'
-        self.browser.getControl(name="form.school_utp").value = ['utp0010']
+        self.browser.getControl(name="form.school_utp").value = ['utp0011']
         self.browser.getControl(name="form.subj_comb").value = ['BEDCERT1']
         image = open(SAMPLE_IMAGE, 'rb')
@@ -329,10 +329,10 @@
         self.assertTrue(
             'Application submitted' in self.browser.contents)
         # Create 10 applicants who already selected utp0010
         for i in range(1,11):
             dummy = createObject(u'waeup.Applicant')
             dummy.firstname = u'John'
             dummy.lastname = u'Doe %s' %i
-            dummy.school_utp = 'utp0010'
+            dummy.school_utp = 'utp0011'
             self.app['applicants'][
                 self.utpcontainer.code].addApplicant(dummy)
@@ -341,5 +341,5 @@
         self.utpapplicant.locked = False
         self.browser.open(self.utpapplicant_path + '/edit')
-        self.browser.getControl(name="form.school_utp").value = ['utp0010']
+        self.browser.getControl(name="form.school_utp").value = ['utp0011']
         self.browser.getControl("Finally Submit").click()
         self.assertTrue("Maximum number of applications per school exceeded."
@@ -329,10 +329,10 @@
         self.assertTrue(
             'Application submitted' in self.browser.contents)
-        # Create 10 applicants who already selected utp0010
+        # Create 10 applicants who already selected utp0011
         for i in range(1,11):
             dummy = createObject(u'waeup.Applicant')
